summaryrefslogtreecommitdiffstats
path: root/include/media/AudioSystem.h
diff options
context:
space:
mode:
authorEric Laurent <elaurent@google.com>2014-07-27 18:38:22 -0700
committerEric Laurent <elaurent@google.com>2014-07-28 21:43:16 +0000
commitde3f8392fbf380ba6f09d009b00d7172477389a2 (patch)
tree77687cb28cf7dfb34ebb6317e246b3cad5672b86 /include/media/AudioSystem.h
parent03524dcc1215b2c468f5c8c8abe6f1c26239fd71 (diff)
downloadframeworks_av-de3f8392fbf380ba6f09d009b00d7172477389a2.zip
frameworks_av-de3f8392fbf380ba6f09d009b00d7172477389a2.tar.gz
frameworks_av-de3f8392fbf380ba6f09d009b00d7172477389a2.tar.bz2
rename AudioSystem::newAudioSessionId()
Rename AudioSystem::newAudioSessionId() to AudioSystem::newAudioUniqueId() as it can be used also for I/O handles. Bug: 12378680. Change-Id: I611ea3b5eb57a4b0774437f477ee87dc4ccc2cc2
Diffstat (limited to 'include/media/AudioSystem.h')
-rw-r--r--include/media/AudioSystem.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/media/AudioSystem.h b/include/media/AudioSystem.h
index 9ea18de..2e3cab0 100644
--- a/include/media/AudioSystem.h
+++ b/include/media/AudioSystem.h
@@ -139,12 +139,12 @@ public:
// return the number of input frames lost by HAL implementation, or 0 if the handle is invalid
static uint32_t getInputFramesLost(audio_io_handle_t ioHandle);
- // Allocate a new audio session ID and return that new ID.
- // If unable to contact AudioFlinger, returns AUDIO_SESSION_ALLOCATE instead.
- // FIXME If AudioFlinger were to ever exhaust the session ID namespace,
- // this method could fail by returning either AUDIO_SESSION_ALLOCATE
- // or an unspecified existing session ID.
- static int newAudioSessionId();
+ // Allocate a new unique ID for use as an audio session ID or I/O handle.
+ // If unable to contact AudioFlinger, returns AUDIO_UNIQUE_ID_ALLOCATE instead.
+ // FIXME If AudioFlinger were to ever exhaust the unique ID namespace,
+ // this method could fail by returning either AUDIO_UNIQUE_ID_ALLOCATE
+ // or an unspecified existing unique ID.
+ static audio_unique_id_t newAudioUniqueId();
static void acquireAudioSessionId(int audioSession, pid_t pid);
static void releaseAudioSessionId(int audioSession, pid_t pid);